* change this line for the work directory
* data sould be in $work/data
global work "~/Dropbox/research/SixteenAndPregnant/6docs/manuscript/IREE/replication/"


capture log close
log using "$work/iree-jjk-replication2.log", replace
****************************************************************************
*
* Replication File
*
* "Tweet Sixteen and Pregnant: Missing Links in the Causal Chain from 
*  Reality TV to Fertility"
* David A. Jaeger, Theodore Joyce, and Robert Kaestner
*
* This paper replicates and extends the results of Kearney, Melissa S. and
* Phillip B. Levine, "Media Influences on Social Outcomes: The Impact of 
* MTV's 16 and Pregnant on Teen Childbearing," American Economic Review 
* 105(12):3597-3632, December 2015 (henceforth KL).
*
* Resubmitted to Interational Re-Views in Empirical Economics, December 2018
*
*
* Data used:]
* The data used come partially from the replication files made available by
* KL on the American Economic Review website, which can be downloaded at
* https://www.aeaweb.org/aer/data/10512/20140012_data.zip
*  
* Tables 1 and 2 use national-level data from Twitter from the file
* topsy-trend-daily.dta, which is included in KL's replication file above.
*
* Table 3  uses data from * the files topsy-state-daily.dta and 
* topsy-state.dta, which are also included in the downloadable zip file.
*
* Table 4 uses national-level data from Google from the file
* googletrends.dta, which was obtained directly from Phil Levine on 
* 28 August 2016.  This file is referenced in KL's replication files on 
* the AER website, but not included in the downloadable zip file.
*
*
****************************************************************************

set more off 

clear

************
* Data:  Figure 1:  National Twitter Results
* Data file obtained from https://www.aeaweb.org/aer/data/10512/20140012_data.zip

use "$work/data/topsy-trend-daily.dta"

tsset trend
sort trend

****
* tweet rates and log tweet rates
* 16p = 16 and Pregnant
* bc = birth control
* abort = abortion

gen twtrate16p = 1000000*tweets16p/totaltweets
gen twtratebc = 1000000*tweetsbc/totaltweets
gen twtrateabort = 1000000*tweetsabort/totaltweets

gen lntwtrate16p = log(twtrate16p)
gen lntwtratebc = log(twtratebc)
gen lntwtrateabort = log(twtrateabort)

label var lntwtrate16p "16 and Pregnant"
label var lntwtratebc "Birth Control"
label var lntwtrateabor "Abortion"

****

****
* Generate dummy variables for different peridos of show
gen date2 =date(date,"MDY")
label var date2 " "
tsset date2, daily

gen year2012=(date2>td(31dec2011))
gen year2011=(date2>td(31dec2010) & date2<td(01jan2012))
gen year2010=(date2>td(31dec2009) & date2<td(01jan2011))
gen year2009=(date2>td(31dec2008) & date2<td(01jan2010))


************


****
* Figure 1:  Log Tweet Rates for 16 and Pregnant, Birth Control, and Abortion
#delimit ;

/* Figure 1, Panel A */

graph twoway
(tsline lntwtratebc if year2010==1, 
lwidth(thin) lcolor(blue) scheme("s1mono") 	
plotregion(lstyle(none))  
xtitle("")
ytitle("Log(Tweet Rates)", size(small)) 
) 

|| 

(tsline lntwtrate16p if year2010==1 , 
lcolor(red) lwidth(thin)
tline(16feb2010 
      23feb2010 
      02mar2010 
      09mar2010 
      16mar2010 
      23mar2010 
      30mar2010 
      06apr2010 
      13apr2010 
      20apr2010 
      26oct2010 
      02nov2010 
      09nov2010 
      16nov2010 
      23nov2010 
      30nov2010 
      06dec2010 
      14dec2010 
      21dec2010 
      28dec2010,
      lcolor(black) lwidth(vthin)) 
tlabel(01feb2010 01jun2010 01sep2010  01dec2010, format(%tdmd) labsize(small))
ylabel(, labsize(small))),
title("{it: Panel A: Birth Control}", size(small))
legend(cols(2)  region(lstyle(none))  size(small) 
   lab(1 "Birth Control") lab(2 "{it:16 and Pregnant}") )
name(Fig1PanelA, replace);


/* Figure 1, Panel B */

graph twoway
(tsline lntwtrateabort if year2010==1, 
lwidth(thin) lcolor(green) scheme("s1mono") 	
plotregion(lstyle(none))  
plotregion(lstyle(none))  
xtitle("")
ytitle("Log(Tweet Rates)", size(small)) 
) 

|| 


(tsline lntwtrate16p if year2010==1 , 
lcolor(red) lwidth(thin) 

tline(16feb2010 
      23feb2010 
      02mar2010 
      09mar2010 
      16mar2010 
      23mar2010 
      30mar2010 
      06apr2010 
      13apr2010 
      20apr2010 
      26oct2010 
      02nov2010 
      09nov2010 
      16nov2010 
      23nov2010 
      30nov2010 
      06dec2010 
      14dec2010 
      21dec2010 
      28dec2010,
      lcolor(black) lwidth(vthin)) 
tlabel(01feb2010 01jun2010 01sep2010  01dec2010, format(%tdmd) labsize(small))
ylabel(, labsize(small))),
title("{it:Panel B: Abortion}", size(small))
legend(cols(2)  region(lstyle(none))  size(small) 
   lab(1 "Abortion") lab(2 "{it:16 and Pregnant}") )
name(Fig1PanelB, replace);

graph combine 
    Fig1PanelA
    Fig1PanelB,
    col(1)  
		ysize(11)
		xsize(8.5)
    xcommon
	  scheme("s1mono")
		title("{stSerif:{bf:Figure 1}}" "{stSerif:Twitter Activity for {it:16 and Pregnant}, Birth Control, and Abortion}"
		      "{stSerif:Season 2 (2010)}", size(2.25) )
		graphregion(margin(11.76 11.76 11.76 11.76))
		note("{stSerif:{it:Notes:}  These graphs plot the log tweet rate for {it:16 and Pregnant}, birth control, and abortion}" 
		     "{stSerif:for the second season (2010) of {it:16 and Pregnant}.  The vertical lines represent the days of}"
	         "{stSerif:broadcasts of {it:16 and Pregnant}.  Note that the vertical scale is different in each panel.}", size(2) )
		;

graph export "$work/Figure1.pdf", replace;

#delimit cr

clear

************


************
* Data:  Figure 2, nationa Twitter results
* Data file obtained from https://www.aeaweb.org/aer/data/10512/20140012_data.zip
* Shading from the corrected "in season" dates referenced under "Broadcast Date Corrections" below

use "$work/data/topsy-trend-daily.dta"

****
* Generate dummy variables for different peridos of show
gen date2 =date(date,"MDY")
label var date2 " "
tsset date2, daily

sort trend
tsset trend

****
* Rescale totaltweets variable (to millions)

gen totaltweetsmillion=totaltweets/1000000


***
* Calculate average weight for different "in season" periods
* Uses corrected "in season" dates described below
* For discussion in text
gen seasonnum=0
replace seasonnum=1 if trend >= 162 & trend <=211
replace seasonnum=2 if trend >= 412 & trend <=475
replace seasonnum=3 if trend >= 664 & trend <=734
replace seasonnum=4 if trend >= 839 & trend <=909
replace seasonnum=5 if trend >= 1182 & trend <= 1252

forvalues s=1/5 {
   summarize totaltweetsmillion if seasonnum==`s'
   }

   
*** 
* Graph

#delimit ;
graph twoway

(function y=80, recast(area) bfcolor(gs12) blcolor(gs12) range(162 211) ) ||
(function y=80, recast(area) bfcolor(gs12) blcolor(gs12) range(412 475) ) ||
(function y=80, recast(area) bfcolor(gs12) blcolor(gs12) range(664 734) ) ||
(function y=80, recast(area) bfcolor(gs12) blcolor(gs12) range(839 909) ) || 
(function y=80, recast(area) bfcolor(gs12) blcolor(gs12) range(1182 1252) ) ||

(line totaltweetsmillion trend, 
lwidth(thin) lcolor(black) scheme("s1mono") 	
plotregion(lstyle(none))  
xtitle("")
ytitle("Total Tweets (millions)", size(vsmall)) 
xlabel(1 "Jan 2009" 366 "Jan 2010" 731 "Jan 2011" 1096 "Jan 2012" 1462 "Jan 2013", labsize(vsmall))
ylabel(, labsize(vsmall))
)

, legend(off)
name(Fig2, replace)
;

graph combine 
    Fig2,
    col(1)  
		ysize(8.5)
		xsize(11)
    
	  scheme("s1mono")
		title("{stSerif:{bf:Figure 2}}" "{stSerif:Total Number of Tweets}"
		      "{stSerif:2009-2012}", size(2.25) )
		graphregion(margin(11.76 11.76 11.76 11.76))
		note("{stSerif:{it:Notes:}  This graph shows the total number of daily tweets from 2008 to 2012, which KL use as weights in }"
		     "{stSerif:the national-level Twitter regressions shown in Table 2. The shaded areas indicate ''in season'' periods}"
			 "{stSerif:for {it:16 and Pregnant}, using the corrected dates as discussed in the text.}", size(2) )
		;

graph export "$work/Figure2.pdf", replace;
#delimit cr

clear

************


************
* Data:  Tables 1 and 2, national Twitter results
* Data file obtained from https://www.aeaweb.org/aer/data/10512/20140012_data.zip

use "$work/data/topsy-trend-daily.dta"

tsset trend
sort trend

****
* tweet rates and log tweet rates
* 16p = 16 and Pregnant
* bc = birth control
* abort = abortion

gen twtrate16p = 1000000*tweets16p/totaltweets
gen twtratebc = 1000000*tweetsbc/totaltweets
gen twtrateabort = 1000000*tweetsabort/totaltweets

gen lntwtrate16p = log(twtrate16p)
gen lntwtratebc = log(twtratebc)
gen lntwtrateabort = log(twtrateabort)

****


****
* Variable labels for KL's "in season" and "day show was broadcast" variables
* 
* showon1 is an indicator for period in which show was airing ("in season")
* showon2 is an indicator for the day on which the show was broadcast
*
* rename KL's variables
rename showon1 inseason
rename showon2 broadcastday

****

****
* Trend quadratic
gen trend2 = trend^2
****

************




************
* Broadcast date corrections
* 
* As noted in the text, 11 of the 53 days on which 16P was broadcast were 
* miscoded by one day, implying that 11 lagged variables were also miscoded 
* by one day. 
*
* We corrected the dates of broadcast using the following sources:
*
* 16 and Pregnant
* 1st season is Jun 2009 - Jul 2009, 
* 2nd season is Feb 2010 - Dec 2010,
* 3rd season is Apr 2011 - Jun 2011.
*
* http://www.mtv.com/shows/16-and-pregnant/episode-guide (official MTV site)
* http://www.tvguide.com/tvshows/16-pregnant/episodes-season-1/304110/
* http://www.tvguide.com/tvshows/16-pregnant/episodes-season-2/304110/
* http://www.tvguide.com/tvshows/16-pregnant/episodes-season-3/304110/
*
*
* Teen Mom and Teen Mom 2
* Teen Mom   1st season is Dec 2009 - Feb 2010
* Teen Mom 2 1st seaons is Jan 2011 - Mar 2011
*
* http://www.mtv.com/shows/teen-mom/episode-guide (teen mom season 1 not listed 
*                                                  by KL Dec 2009 - Feb 2010)
* http://www.mtv.com/shows/teen-mom-2/episode-guide  
*
* We cannot find 16P, Teen Mom, or Teen Mom2 broadcast in Feb 2010 - Apr 2010
*
* These are KL's "in season" dates, which which are incorrect:
* period 1 = 1/1/2009 - 6/10/2009: off
* period 2 = 6/11/2009 - 7/31/2009: on
* period 3 = 8/1/2009 - 2/15/2010: off
* period 4 = 2/16/2010 - 4/20/2010: on
* period 5 = 4/21/2010 - 10/25/2010: off
* period 6 = 10/26/2010 - 1/5/2011: on
* period 7 = 1/6/2011 - 4/18/2011: off
* period 8 = 4/19/2011 - 6/28/2011: on
* period 9 = 6/29/2011 - 3/20/2012: off
* period 10 = 3/21/2012 - 6/6/2012: on
* period 11 = 6/7/2012 - 12/31/2012: off
* 
* These are the correct "in season" dates according to the TV guide sites above
* period 1 = 1/1/2009 - 6/10/2009: off
* period 2 = 6/11/2009 - 7/30/2009: on
* period 3 = 7/31/2009 - 2/15/2010: off
* period 4 = 2/16/2010 - 4/20/2010: on
* period 5 = 4/21/2010 - 10/25/2010: off
* period 6 = 10/26/2010 - 1/4/2011: on
* period 7 = 1/5/2011 - 4/18/2011: off
* period 8 = 4/19/2011 - 6/28/2011: on
* period 9 = 6/29/2011 - 3/26/2012: off
* period 10 = 3/27/2012 - 6/5/2012: on
* period 11 = 6/6/2012 - 12/31/2012: off
*
************

****
* Create corrected "in season" and "broadcast day" variables
* r_ prefix variables indicate using revised dates
gen r_broadcastday=broadcastday
gen r_inseason=inseason

                                                 
replace r_broadcastday=1 if date=="7/23/2009"    
replace r_broadcastday=0 if date=="7/24/2009"    
                                                 
replace r_broadcastday=1 if date=="7/30/2009"    
replace r_broadcastday=0 if date=="7/31/2009"    
replace r_inseason    =0 if date=="7/31/2009"    
                                                                                             
replace r_broadcastday=1 if date=="1/4/2011"     
replace r_broadcastday=0 if date=="1/5/2011"     
replace r_inseason    =0 if date=="1/5/2011"  

replace r_broadcastday=0 if date=="3/21/2012"       
                                                 
replace r_broadcastday=1 if date=="4/24/2012"    
replace r_broadcastday=0 if date=="4/25/2012"                                                  
                                                 
replace r_broadcastday=1 if date=="5/1/2012"     
replace r_broadcastday=0 if date=="5/2/2012"     
                                                 
replace r_broadcastday=1 if date=="5/8/2012"     
replace r_broadcastday=0 if date=="5/9/2012"     
                                                 
replace r_broadcastday=1 if date=="5/15/2012"    
replace r_broadcastday=0 if date=="5/16/2012"    
                                                 
replace r_broadcastday=1 if date=="5/22/2012"    
replace r_broadcastday=0 if date=="5/23/2012"    
                                                                                   
replace r_broadcastday=1 if date=="5/29/2012"    
replace r_broadcastday=0 if date=="5/30/2012"    
replace r_broadcastday=0 if date=="5/31/2012"    
                                                                                                
replace r_broadcastday=1 if date=="6/5/2012"   
replace r_broadcastday=0 if date=="6/6/2012"
replace r_inseason    =0 if date=="6/6/2012"

************

************
* Create lagged broadcast days
* Note:  doing this here to have 1/1/2009 as zero rather than missing
gen L_broadcastday=L.broadcastday
replace L_broadcastday=0 if L_broadcastday==.

gen L_r_broadcastday=L.r_broadcastday
replace L_r_broadcastday=0 if L_r_broadcastday==.

************

************
* Create indicators for various broadcast and non-broadcast days

***
* Create pre-16 and Pregnant indicator
* numdate==18059 is 11 June 2009, the first day of 16P broadcast
gen numdate=date(date,"MDY")
gen pre16p=numdate<18059

***
* Create "out of season" indicator (0 in pre-16P period)
gen r_outofseason=1-r_inseason
replace r_outofseason=0 if pre16p==1 | L_r_broadcastday==1

***

************



************
* Replicate KL's results for our Table 1, columns 2 and 5
* and our Table 2, columns 1 and 4
*
* Note that the indicator for the day after the show is on is calculated 
* incorrectly because KL first drop observations that are not "in season" 
* (inseason==0) and then create the lag indicator for the day after a 
* broadcast of 16P using the _n-1 construction:   broadcastday[_n-1] == 1
*
* See footnotes 11 and 13

* Preserve all data
preserve


* keep only "in season" observations
keep if inseason

****
* Indicator for day after show:  Now that because keeping only "in season" observations
* means that the periods are non-contiguous, creating the lag at this point is incorrect
gen lagbroadcastday = broadcastday[_n-1] == 1


****
* Replicate KL's (incorrect) results

* Replicate KL Table 3, column 4 (corresponds to our Table 1, column 2 below)
reg lntwtratebc    broadcastday lagbroadcastday trend trend2 [weight=totaltweets], robust

* Replicate KL Table 3, column 5 (corresponds to our Table 1, column 5 below)
reg lntwtrateabort broadcastday lagbroadcastday trend trend2 [weight=totaltweets],  robust

* Replicate KL Table 4, panel A, column 4 (corresponds to our Table 2, column 1 below)
reg lntwtratebc    lntwtrate16p trend trend2 [weight=totaltweets], robust

* Replicate KL Table 4, panel A, column 5 (corresponds to our Table 1, column 5 below)
reg lntwtrateabort lntwtrate16p trend trend2 [weight=totaltweets],  robust

****

* Restore full data set
restore

***********




***********
* Table 1 Results:  Association between 16P broadcast days and Twitter activity

****
* Column 1:  Association betweeen tweet rate and broadcast of 16P, all dates
newey lntwtrate16p r_broadcastday L_r_broadcastday trend trend2 pre16p r_outofseason, lag(1) force 
lincom r_broadcastday   - pre16p   
lincom L_r_broadcastday - pre16p      
lincom r_broadcastday   - r_outofseason 
lincom L_r_broadcastday - r_outofseason 

****
* Column 2:  Birth control tweets, Replicate KL Table 3, column 2, with uncorrected dates but correct lag variables, "in season" only
reg lntwtratebc broadcastday L_broadcastday trend trend2 [weight=totaltweets] if inseason==1, robust

****
* Column 3:  Birth control tweets, Replicate KL Table 3, column 2, with corrected dates and correct lag variables, "in season" only
reg lntwtratebc r_broadcastday L_r_broadcastday trend trend2 [weight=totaltweets] if r_inseason==1, robust

****
* Column 4:  Birth control tweets, Replicate KL Table 3, column 2, with corrected dates and correct lag variables, "in season" only, no weights
reg lntwtratebc r_broadcastday L_r_broadcastday trend trend2 if r_inseason==1, robust


****
* Column 5:  Birth control tweets, Corrected dates and correct lag variables, all dates
reg lntwtratebc r_broadcastday L_r_broadcastday trend trend2 pre16p r_outofseason [weight=totaltweets] , robust
lincom r_broadcastday   - pre16p   
lincom L_r_broadcastday - pre16p      
lincom r_broadcastday   - r_outofseason 
lincom L_r_broadcastday - r_outofseason 

****
* Column 6:  Birth control tweets, Corrected dates and correct lag variables, all dates
newey lntwtratebc r_broadcastday L_r_broadcastday trend trend2 pre16p r_outofseason, lag(1) force
lincom r_broadcastday   - pre16p   
lincom L_r_broadcastday - pre16p      
lincom r_broadcastday   - r_outofseason 
lincom L_r_broadcastday - r_outofseason 

****
* Column 7:  Abortion tweets, Replicate KL Table 2, column 5 with uncorrected dates but correct lag variables,"in season" only
reg lntwtrateabort broadcastday L_broadcastday trend trend2 [weight=totaltweets] if inseason==1, robust

****
* Column 8:  Abortion tweets, Replicate KL Table 2, column 5 with corrected dates and lag variables, "in season" only
reg lntwtrateabort r_broadcastday L_r_broadcastday trend trend2 [weight=totaltweets] if r_inseason==1, robust

****
* Column 9:  Abortion tweets, Replicate KL Table 2, column 5 with corrected dates and lag variables, "in season" only, no weights
reg lntwtrateabort r_broadcastday L_r_broadcastday trend trend2  if r_inseason==1, robust


****
* Column 10:  Abortion tweets, Corrected dates and correct lag variables, all dates
reg lntwtrateabort r_broadcastday L_r_broadcastday trend trend2 pre16p r_outofseason [weight=totaltweets], robust
lincom r_broadcastday   - pre16p   
lincom L_r_broadcastday - pre16p      
lincom r_broadcastday   - r_outofseason 
lincom L_r_broadcastday - r_outofseason 

****
* Column 11:  Abortion tweets, Corrected dates and correct lag variables, all dates
newey lntwtrateabort r_broadcastday L_r_broadcastday trend trend2 pre16p r_outofseason, lag(1) force
lincom r_broadcastday   - pre16p   
lincom L_r_broadcastday - pre16p      
lincom r_broadcastday   - r_outofseason 
lincom L_r_broadcastday - r_outofseason 

************




************
* Table 2 Results:  Association between Log(16P Tweets) and Twitter Activity



****
* Column 1 Birth control tweets, Replicate KL Table 4, column 4 
reg lntwtratebc lntwtrate16p trend trend2 [weight=totaltweets] if r_inseason==1, robust

****
* Column 2 Birth control tweets, Replicate KL Table 4, column 4 without weights
reg lntwtratebc lntwtrate16p trend trend2  if r_inseason==1, robust


****
* Column 3 Birth control tweets, all dates
reg lntwtratebc lntwtrate16p trend trend2 [weight=totaltweets] if pre16p==0, robust


****
* Column 4 Birth control tweets, all dates, Newey-West
newey lntwtratebc lntwtrate16p trend trend2 if pre16p==0, lag(1) force


****
* Column 5 Abortion tweets, Replicate KL Table 4, column 4 
reg lntwtrateabort lntwtrate16p trend trend2 [weight=totaltweets] if r_inseason==1, robust

****
* Column 6 Abortion tweets, Replicate KL Table 4, column 4, without weights
reg lntwtrateabort lntwtrate16p trend trend2  if r_inseason==1, robust

****
* Column 7 Abortion tweets, all dates
reg lntwtrateabort lntwtrate16p trend trend2 [weight=totaltweets] if pre16p==0, robust


****
* Column 8 Abortion tweets, all dates, Newey-West
newey lntwtrateabort lntwtrate16p trend trend2 if pre16p==0, lag(1) force


clear


************

************
* Data:  Table 3, State-level Twitter trends
* Data file obtained from https://www.aeaweb.org/aer/data/10512/20140012_data.zip
use "$work/data/topsy-state-daily.dta"

****
* Calculate total tweets by state and period
sort stname period
collapse (sum) totaltweets, by(stname period)
sort stname period
save "$work/temp.dta", replace

clear

****

****
* Merge total tweets into state-by-period dataset
use "$work/data/topsy-state.dta"
drop totaltweets
drop if stname == "PR"
sort stname period
merge 1:1 stname period using "$work/temp.dta"
rm "$work/temp.dta"

****

****
* Generate tweet rate variables

gen twtrate16p = 1000000*tweets16p/totaltweets
gen twtratebc = 1000000*tweetsbc/totaltweets
gen twtrateabort = 1000000*tweetsabort/totaltweets
gen twtrateadopt = 1000000*tweetsadopt/totaltweets
gen lntwtrate16p = log(twtrate16p)
gen lntwtratebc = log(twtratebc)
gen lntwtrateabort = log(twtrateabort)
gen lntwtrateadopt = log(twtrateadopt)

****

****
* drop observations if missing any of relevant tweet variables

drop if twtrate16p == 0 | twtrateabort == 0 | twtratebc == 0

****



****************
* Table 3, State-level Twitter Results

gen logtotaltweets=log(totaltweets)

****
* Column 1:  Association between tweet rate for birth control and tweet rate for 16 and pregnant, weighted
areg lntwtratebc lntwtrate16p i.period [aw=totaltweets], absorb(stname) robust cluster(stname)


****
* Column 2:  Association between tweet rate for birth control and tweet rate for 16 and pregnant, unweighted
areg lntwtratebc lntwtrate16p i.period, absorb(stname) robust cluster(stname)


****
* Column 3:  Association between tweet rate for abortion and tweet rate for 16 and pregnant, weighted
areg lntwtrateabort lntwtrate16p i.period [aw=totaltweets], absorb(stname) robust cluster(stname)


****
* Column 4:  Association between tweet rate for abortion and tweet rate for 16 and pregnant, unweighted
areg lntwtrateabort lntwtrate16p i.period, absorb(stname) robust cluster(stname)

clear

****************



************
* Data:  Table 4, Google Results
* Data file obtained directly from Phil Levine on 28 August 2016 
* This file is referenced in KL's replication files on the AER website, but not 
* included in the downloadable zip file.
*
* Variables:
* new16p is an indicator variable for week with new 16 and Pregnant broadcast.
* index16p is the Google Trends index for 16 and Pregnant
* howgetbc is the Google Trends index for "How to get birth control"
* howgetabort is the Google Trends index for "How to get an abortion"
* howgetpill is the Google Trends index for "How to get birth control pill"

use "$work/data/googletrends.dta"
tsset trend


************



************
* Table 4:  Results

****
* Column 1:  Association between Google searches for 16P and 16P broadcast week
reg index16p new16p trend trend2 i.month 
newey index16p new16p trend trend2 i.month, lag(1) force 

****
* Column 2:  Association between Google searches for birth control and 16P broadcast week
reg howgetbc new16p trend trend2 i.month 
newey howgetbc new16p trend trend2 i.month, lag(1) force

****
* Column 3:  Association between Google searches for birth control and Google searches for 16P
* Replicates KL Table 4, Panel A, column 1
reg howgetbc index16p trend trend2 i.month 
newey howgetbc index16p trend trend2 i.month, lag(1) force

****
* Column 4:  Association between Google searches for birth control pill and 16P broadcast week
reg howgetpill new16p trend trend2 i.month
newey howgetpill new16p trend trend2 i.month, lag(1) force

****
* Column 5:  Association between Google searches for birth control pill and Google searches for 16P
* Replicates KL Table 4, Panel A, column 2
reg howgetpill index16p trend trend2 i.month 
newey howgetpill index16p trend trend2 i.month, lag(1) force

****
* Column 6:  Association between Google searches about abortion and 16P broadcast week
reg howgetabort new16p trend trend2 i.month 
newey howgetabort new16p trend trend2 i.month, lag(1) force

****
* Column 7:  Association between Google searches about abortion and Google searches for 16P
* Replicates KL Table 4, Panel A, column 3
reg howgetabort index16p trend trend2 i.month 
newey howgetabort index16p trend trend2 i.month, lag(1) force


clear 

************


************
* Data: Replicating State-level Google searches
* Data file obtained from https://www.aeaweb.org/aer/data/10512/20140012_data.zip
*
* See footnote 17
*
use "$work/data/googletrends-state.dta"

****
* Create state categorical variable
quietly encode stname, gen(state)

****
* Create 2nd period dummy variable
gen yeardv=(year==200910)
************


************
* Replication State-Level Google Results

****
* Association between Google searches for Birth Control and Google searches for 16 and Pregnant, weighted
reg hgbc index16p yeardv i.state [weight=fempop]

****
* Association between Google searches for Birth Control and Google searches for 16 and Pregnant, unweighted
reg hgbc index16p yeardv i.state 

****
* Association between Google searches for Birth Control and Google searches for 16 and Pregnant, weighted
reg hgabort index16p yeardv i.state [weight=fempop]

****
* Association between Google searches for Birth Control and Google searches for 16 and Pregnant, unweighted
reg hgabort index16p yeardv i.state 


clear

************





capture log close



